=============================
profile-middleware
=============================

.. image:: https://badge.fury.io/py/profiler.png
    :target: https://badge.fury.io/py/profiler

.. image:: https://travis-ci.org/vinu76jsr/profiler.png?branch=master
    :target: https://travis-ci.org/vinu76jsr/profiler

.. image:: https://coveralls.io/repos/vinu76jsr/profiler/badge.png?branch=master
    :target: https://coveralls.io/r/vinu76jsr/profiler?branch=master

Profiler for django views

Documentation
-------------

The full documentation is at https://profiler.readthedocs.org.

Quickstart
----------

Install profile-middleware::

    pip install profiler

Then use it in a project::

    import profiler

Features
--------

* TODO